@@ -11,84 +11,6 @@ from . import utils
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
 
-
-def dynamodb_generate_json_from_csv_in_s3(bucket, key, delimiter=","):
-    """takes a bucket and key and returns a dynamodb json formatted payload"""
-    logger.debug(f"")
-
-    file = s3_download(bucket, key)
-    logger.info(f"file: {file}")
-    data = utils.make_json_from_csv(file, delimiter)
-    logger.debug(f"data: {data}")
-
-    output = []
-    for row in data:
-        item = dynamodb_format_json(row)
-        output.append(item)
-        logger.debug(f"item: {item}")
-
-    os.remove(file)
-    return output
-
-
-def dynamodb_translate_data_type(data):
-
-    data_type = str(type(data))
-
-    if data_type == "<class 'str'>":
-        if " ".join(data.split()) == "":
-            return {"NULL": True}
-        return {"S": " ".join(data.split())}
-    if data_type in ["<class 'int'>", "<class 'float'>", "<class 'complex'>"]:
-        return {"N": data}
-    if data_type == "<class 'list'>":
-        return {"L": [dynamodb_translate_data_type(item) for item in data]}
-    if data_type == "<class 'dict'>":
-        return {"M": {key: dynamodb_translate_data_type(value) for key, value in data.items()}}
-    if data_type == "<class 'bool'>":
-        return {"BOOL": data}
-    if data_type == "<class 'NoneType'>":
-        return {"NULL": True}
-
-
-def dynamodb_put_item(table_name, data):
-    """puts an item to dynamodb"""
-    logger.debug(f'dynamodb_put_item("{table_name}", "{data}") called')
-
-    s = boto3.session.Session()
-    c = s.client("dynamodb")
-    logger.info("boto3 dynamodb client created")
-
-    try:
-        c.put_item(TableName=table_name, Item=data)
-    except botocore.exceptions.ClientError as e:
-        logger.exception("error while putting the item to dynamodb")
-        raise e
-    else:
-        logger.info(f"{data} put to {table_name}")
-
-
-def dynamodb_format_json(data):
-    """formats the dynamodb json"""
-    logger.debug(f"dynamodb_format_json('{data}') called")
-
-    output = {}
-    keys = list(data.keys())
-    for key in keys:
-        output[key] = dynamodb_translate_data_type(data[key])
-    return output
-
-
-def dynamodb_add_nested_json(pk_name, pk_value, data):
-    """generates the nested data to add to a dynamodb item"""
-    output = []
-    for row in data:
-        if row[pk_name]["S"] == pk_value:
-            output.append({"M": row})
-
-    return output
-
-
 def sqs_delete_message(receipt_handle, queue_url):
     """deletes a message from the SQS queue"""
     logger.debug(f"sqs_delete_message('{receipt_handle}') called")
