@@ -1,6 +1,8 @@
 import csv
 import json
 import logging
+import random
+import string
 
 import psycopg2
 
@@ -78,6 +80,10 @@ def get_file_extension(file):
     return extension
 
 
+def randStr(chars=string.ascii_letters + string.digits, N=2):
+    return "".join(random.choice(chars) for _ in range(N))
+
+
 class Postgres:
     def __init__(self, secrets_manager_key=None, host=None, port=None, user=None, password=None, dbname=None):
         self.secrets_manager_key = secrets_manager_key
